@@ -426,7 +426,7 @@ ctStanMatricesList <- function(unsafe=FALSE){
   base <- c(PARS=10, T0MEANS=1,LAMBDA=2,DRIFT=3,DIFFUSION=4,MANIFESTVAR=5,MANIFESTMEANS=6, CINT=7,
     T0VAR=8,TDPREDEFFECT=9)
   jacobian = c(JAx=52,Jtd=53,Jy=54) #J0=51,
-  asymptotic = c(asymCINT=21,asymDIFFUSION=22)
+  asymptotic = c(asymCINT=21,asymDIFFUSIONcov=22)
   extra <- c(DIFFUSIONcov=31,MANIFESTcov=32,T0cov=33)
   all <- c(base,jacobian,asymptotic, extra)
   mn <- list(base=base, jacobian=jacobian, asymptotic=asymptotic, extra=extra,all=all)
@@ -610,7 +610,7 @@ ctStanModelMatrices <-function(ctm){
   })
   
   #special matrix adjustments
-  matrixdims[mats$all[names(mats$all ) == 'asymDIFFUSION'],] <- 
+  matrixdims[mats$all[names(mats$all ) == 'asymDIFFUSIONcov'],] <- 
     matrixdims[mats$all[names(mats$all ) == 'DIFFUSIONcov'],] <- 
     matrixdims[mats$all[names(mats$all ) == 'DIFFUSION'],]
   matrixdims[mats$all[names(mats$all ) == 'asymCINT'],] <- 
@@ -938,13 +938,13 @@ ctStanModelWriter <- function(ctm, gendata, extratforms,matsetup,simplify=TRUE){
   //dynamic system matrices
   ',subjectparaminit(pop=FALSE,smats=TRUE),'
   
-  asymDIFFUSION = rep_matrix(0,nlatent,nlatent); //in case of derrindices need to init
+  asymDIFFUSIONcov = rep_matrix(0,nlatent,nlatent); //in case of derrindices need to init
   DIFFUSIONcov = rep_matrix(0,nlatent,nlatent);
 
-  for(si in 0:max(subject)){
+  for(si in 0:(dokalman ? max(subject) : 0)){
   for(rowi in 1:ndatapoints){
     if( (rowi==1 && si==0) ||
-      (dokalman && dokalmanrows[rowi] && subject[rowi]==si) ){ //if doing this row for this subject
+      (dokalmanrows[rowi] && subject[rowi]==si) ){ //if doing this row for this subject
     
     int full = (dosmoother==1 || si ==0);
     int o[full ? nmanifest : nobs_y[rowi]]; //which obs are not missing in this row
@@ -1078,10 +1078,10 @@ if(verbose > 1) print ("below t0 row ", rowi);
                 } else eJAx[1:nlatent, 1:nlatent] = discreteDRIFT;
                                
                 if(si==0 || statedep[4]||statedep[52]|| (T0check==1 && (whenmat[4,5] || whenmat[3,5]))){ //if first pass, state dependent, or individually varying drift / diffusion
-                  asymDIFFUSION[derrind,derrind] = ksolve(JAx[derrind,derrind], DIFFUSIONcov[derrind,derrind],verbose);
+                  asymDIFFUSIONcov[derrind,derrind] = ksolve(JAx[derrind,derrind], DIFFUSIONcov[derrind,derrind],verbose);
                 }
-                discreteDIFFUSION[derrind,derrind] =  asymDIFFUSION[derrind,derrind] - 
-                  quad_form_sym( asymDIFFUSION[derrind,derrind], eJAx[derrind,derrind]\' );
+                discreteDIFFUSION[derrind,derrind] =  asymDIFFUSIONcov[derrind,derrind] - 
+                  quad_form_sym( asymDIFFUSIONcov[derrind,derrind], eJAx[derrind,derrind]\' );
               }
             }
             
@@ -1215,7 +1215,7 @@ if(verbose > 1){
             "  DRIFT =", DRIFT, " DIFFUSION =", DIFFUSION, 
             " CINT =", CINT, "  discreteCINT = ", discreteCINT, "  MANIFESTcov ", (MANIFESTcov), "  MANIFESTMEANS ", MANIFESTMEANS, 
             "  T0cov", T0cov,  " T0MEANS ", T0MEANS, "LAMBDA = ", LAMBDA, "  Jy = ",Jy,
-            " discreteDRIFT = ", discreteDRIFT, "  discreteDIFFUSION ", discreteDIFFUSION, "  asymDIFFUSION ", asymDIFFUSION, 
+            " discreteDRIFT = ", discreteDRIFT, "  discreteDIFFUSION ", discreteDIFFUSION, "  asymDIFFUSIONcov ", asymDIFFUSIONcov, 
             " DIFFUSIONcov = ", DIFFUSIONcov,
             " eJAx = ", eJAx,
             "  rawpopsd ", rawpopsd,  "  rawpopsdbase ", rawpopsdbase, "  rawpopmeans ", rawpopmeans );
@@ -1265,7 +1265,7 @@ if(verbose > 1){
     if(si==0 || //on either pop pars only
     (  (sum(whenmat[3,])+sum(whenmat[4,])+statedep[3]+statedep[4]) > 0 && savesubjectmatrices) ){ // or for each subject
   
-      asymDIFFUSION[ derrind, derrind ] = 
+      asymDIFFUSIONcov[ derrind, derrind ] = 
         to_matrix( (add_diag( -sqkron_prod(JAx[ derrind, derrind ], JAx[ derrind, derrind ]),1)) \\  
           to_vector(DIFFUSIONcov[ derrind, derrind ]), ndiffusion, ndiffusion);
     }
@@ -1359,7 +1359,7 @@ subjectparaminit<- function(popmats=FALSE,smats=TRUE,matrices=c(mats$base,31, 32
   return(out)
 }
 
-collectsubmats <- function(popmats=FALSE,matrices=c(mats$base,31, 32,33,21,22)){ #'DIFFUSIONcov','MANIFESTcov','asymDIFFUSION','asymCINT'
+collectsubmats <- function(popmats=FALSE,matrices=c(mats$base,31, 32,33,21,22)){ #'DIFFUSIONcov','MANIFESTcov','asymDIFFUSIONcov','asymCINT'
   ma <- ctStanMatricesList()$all
   out<-''
   for(mn in matrices){
@@ -1400,24 +1400,30 @@ int[] whichequals(int[] b, int test, int comparison){  //return array of indices
   }
 
  
-   matrix constraincorsqrt(matrix mat){ //converts from unconstrained lower tri matrix to cor
+   matrix constraincorsqrt(matrix mat,int choleskymats){ //converts from unconstrained lower tri matrix to cor
     matrix[rows(mat),cols(mat)] o;
-  
+
     for(i in 1:rows(o)){ //set upper tri to lower
-      for(j in min(i+1,rows(mat)):rows(mat)){
-        o[j,i] =  inv_logit(mat[j,i])*2-1;  // can change cor prior here
-        o[i,j] = o[j,i];
+      for(j in 1:rows(mat)){
+        if(j > i){
+          o[j,i] =  inv_logit(mat[j,i])*2-1; //divide by i for approx whole matrix equiv priors  
+          o[i,j] = 0;
+        }
       }
-      o[i,i]=.999; //avoids correlations of 1
-      o[i,] /= sqrt(sum(square(o[i,]))+1e-10);
+      o[i,i]=0; 
+      o[i,i] = 1-sqrt(sum(square(o[i,]))+1e-10);
     }
     return o;
   } 
 
-  matrix sdcovsqrt2cov(matrix mat, int cholbasis){ //covariance from cholesky or unconstrained cor sq root
-    if(cholbasis==0)  {
-      return(tcrossprod(diag_pre_multiply(diagonal(mat),constraincorsqrt(mat))));
-    } else return(tcrossprod(mat));
+  matrix sdcovsqrt2cov(matrix mat, int choleskymats){ //covariance from cholesky or unconstrained cor sq root
+    if(choleskymats< 1) {
+      //if(choleskymats== -1){
+        return(multiply_lower_tri_self_transpose(diag_pre_multiply(diagonal(mat),constraincorsqrt(mat,choleskymats))));
+      //} else {
+      //  return(quad_form_diag(constraincorsqrt(mat,choleskymats),diagonal(mat)));
+      //}
+      } else return(tcrossprod(mat));
   }
 
   matrix sqkron_prod(matrix mata, matrix matb){
@@ -1703,6 +1709,7 @@ data {
   int llsinglerow;
   int laplaceprior[nparams];
   int laplaceprioronly;
+  int laplacetipreds;
   int CINTnonzerosize;
   int CINTnonzero[CINTnonzerosize];
   int JAxDRIFTequiv;
@@ -1748,7 +1755,7 @@ transformed parameters{
 
 ',if(!gendata) paste0('
   real ll = 0;
-  vector[ndatapoints] llrow = rep_vector(0,ndatapoints);
+  vector[dokalman ? ndatapoints : 1] llrow = rep_vector(0,dokalman ? ndatapoints : 1);
   matrix[nlatentpop,nlatentpop] etacova[3,savescores ? ndatapoints : 0];
   matrix[nmanifest,nmanifest] ycova[3,savescores ? ndatapoints : 0];
   vector[nlatentpop] etaa[3,savescores ? ndatapoints : 0];
@@ -1796,7 +1803,9 @@ transformed parameters{
         }
       }
     }
-    rawpopcorr = tcrossprod( constraincorsqrt(rawpopcovbase));
+    //if(choleskymats==0) rawpopcorr = constraincorsqrt(rawpopcovbase,choleskymats);
+    //if(choleskymats== -1) 
+    rawpopcorr = multiply_lower_tri_self_transpose( constraincorsqrt(rawpopcovbase,choleskymats));
     rawpopcov = makesym(quad_form_diag(rawpopcorr, rawpopsd +1e-8),verbose,1);
     rawpopcovchol = cholesky_decompose(rawpopcov); 
   }//end indvarying par setup
@@ -1811,7 +1820,8 @@ model{
   if(intoverpop==0 && nindvarying > 0) target+= multi_normal_cholesky_lpdf(baseindparams | rep_vector(0,nindvarying), IIlatentpop[1:nindvarying,1:nindvarying]);
 
   if(ntipred > 0){ 
-    if(nopriors==0) target+= dokalmanpriormodifier * normal_lpdf(tipredeffectparams / tipredeffectscale| 0, 1);
+    if(nopriors==0 && laplacetipreds==0) target+= dokalmanpriormodifier * normal_lpdf(tipredeffectparams / tipredeffectscale| 0, 1);
+    if(nopriors==0 && laplacetipreds==1) target+= dokalmanpriormodifier * double_exponential_lpdf(tipredeffectparams / tipredeffectscale| 0, 1);
     target+= normal_lpdf(tipredsimputed| 0, tipredsimputedscale); //consider better handling of this when using subset approach
   }
 
