@@ -24,10 +24,10 @@ test_that("anomauth", {
   # sink('bad.txt')
   sf=ctStanFit(ctDeintervalise(ctWideToLong(AnomAuth,Tpoints = AnomAuthmodel$Tpoints,n.manifest = 2)),
     ctstanmodel = sm, optimize=TRUE,verbose=1,savescores = FALSE,cores=cores,nopriors=TRUE,#forcerecompile = T,
-    optimcontrol=list(finishsamples=500),plot=FALSE,fit=T)
+    optimcontrol=list(finishsamples=500),plot=0,fit=T)
   # sink()
   print(Sys.time()-a)
-  testthat::expect_equal(23415.929,-2*sf$stanfit$optimfit$value,tolerance=.01)
+  testthat::expect_equal(23415.929,-2*sf$stanfit$optimfit$value,tolerance=.0001)
   anoms=summary(sf)
   anoms$popmeans['mm_Y1','sd']
   testthat::expect_equivalent(.036,anoms$popmeans['mm_Y1','sd'],tolerance=.008)
